From b4c5ed1d8fee7b69a079ee883344bf483faf7a52 Mon Sep 17 00:00:00 2001
From: Xi Lu <lx@shellcodes.org>
Date: Sat, 25 Mar 2023 14:44:35 +0800
Subject: [PATCH] Fix eww--download-directory on Windows.

* lisp/net/eww.el: Add get the download directory on MS-Windows.
---
 lisp/net/eww.el | 17 ++++++++++-------
 1 file changed, 10 insertions(+), 7 deletions(-)

diff --git a/lisp/net/eww.el b/lisp/net/eww.el
index 859a9b44bcb..ac3af4677b5 100644
--- a/lisp/net/eww.el
+++ b/lisp/net/eww.el
@@ -66,14 +66,17 @@ eww-use-browse-url
 
 (defun eww--download-directory ()
   "Return the name of the download directory.
-If ~/Downloads/ exists, that will be used, and if not, the
-DOWNLOAD XDG user directory will be returned.  If that's
+If ~/Downloads/ or %USERPROFILE% on Windows exists, that will be used,
+and if not, the DOWNLOAD XDG user directory will be returned. If that's
 undefined, ~/Downloads/ is returned anyway."
-  (or (and (file-exists-p "~/Downloads/")
-           "~/Downloads/")
-      (when-let ((dir (xdg-user-dir "DOWNLOAD")))
-        (file-name-as-directory dir))
-      "~/Downloads/"))
+  (let ((download-dir (if (eq system-type 'windows-nt)
+                          (concat (getenv "USERPROFILE") "\\Downloads\\")
+                        (concat (getenv "HOME") "/Downloads/"))))
+    (or (and (file-exists-p download-dir)
+             download-dir)
+        (when-let ((dir (xdg-user-dir "DOWNLOAD")))
+          (file-name-as-directory dir))
+        download-dir)))
 
 (defcustom eww-download-directory 'eww--download-directory
   "Directory where files will downloaded.
-- 
2.39.2

